@@ -116,9 +116,11 @@ Service::Result ArtistInfo::processData(const std::string &data)
 			rx.assign("<link rel=\"original\" href=\"(.*?)\"");
 			if (boost::regex_search(data, what, rx))
 			{
+				std::string url = what[1], wiki;
+				// unescape &amp;s
+				unescapeHtmlEntities(url);
 				// ...try to get the content of it...
-				std::string wiki;
-				CURLcode code = Curl::perform(wiki, what[1]);
+				CURLcode code = Curl::perform(wiki, url, "", true);
 				
 				if (code != CURLE_OK)
 				{
@@ -128,7 +130,7 @@ Service::Result ArtistInfo::processData(const std::string &data)
 				else
 				{
 					// ...and filter it to get the whole description.
-					rx.assign("<div id=\"wiki\">(.*?)</div>");
+					rx.assign("<div class=\"wiki\">(.*?)</div>");
 					if (boost::regex_search(wiki, what, rx))
 						desc = unescapeHtmlUtf8(what[1]);
 				}
@@ -155,12 +157,12 @@ Service::Result ArtistInfo::processData(const std::string &data)
 	auto add_similars = [&result](boost::sregex_iterator &it, const boost::sregex_iterator &last) {
 		for (; it != last; ++it)
 		{
-			std::string name = it->str(1);
+			std::string value = it->str(1);
 			std::string url = it->str(2);
-			stripHtmlTags(name);
+			stripHtmlTags(value);
 			stripHtmlTags(url);
 			result.second += "\n * ";
-			result.second += name;
+			result.second += value;
 			result.second += " (";
 			result.second += url;
 			result.second += ")";
